==> tex-guy_1.2.4.orig.tar.gz: tex-guy-1.2.4.orig/xgdvi-1.6.1/buff.h <==
/*  XGDVI
 *  Copyright (C) 1999  Hirotsugu Kakugawa
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

extern void  buffer_init(void);
extern int   buffer_check_in_buffer(char *f);
extern int   buffer_full(void);
extern int   buffer_empty(void);
extern int   buffer_size(void);
extern void  buffer_save_current_state(void);
extern int   buffer_add(DVI_DEVICE v, char *f, DVI d, DVI_PROPERTY p, 
			int g, int pid, int oid, int gpos);
extern char *buffer_file_name(int i, int *f_page, 
			      int *f_paper, int *f_oritent, double *f_shrink, 
			      double *f_pos_x, double *f_pos_y);
extern int   buffer_set_colors(char *f, double r, double g, double b);
extern int   buffer_get_colors(char *f, double *r, double *g, double *b);
extern int   buffer_kill(char *f);
extern int   buffer_update_dvi(char *f, DVI dvi_new);
extern int   buffer_select(char *f);
extern int   buffer_select_any_other(char *f);
extern void  buffer_select_next(int next);

extern int   buffer_dump(void);

==> tex-guy_1.3.2.orig.tar.gz: tex-guy-1.3.2/xgdvi-1.6.5/buff.h <==
/*  XGDVI
 *  Copyright (C) 1999  Hirotsugu Kakugawa
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef __BUFF_H__

#define __BUFF_H__

#include "imgcache.h"

extern void  buffer_init(void);
extern int   buffer_check_in_buffer(char *f);
extern int   buffer_full(void);
extern int   buffer_empty(void);
extern int   buffer_size(void);
extern void  buffer_save_current_state(void);
extern int   buffer_add(DVI_DEVICE v, char *f, DVI d, DVI_PROPERTY p, 
			int g, int pid, int oid, int gpos);
extern char *buffer_file_name(int i, int *f_page, 
			      int *f_paper, int *f_oritent, double *f_shrink, 
			      double *f_pos_x, double *f_pos_y);
extern int   buffer_set_colors(char *f, double r, double g, double b);
extern int   buffer_get_colors(char *f, double *r, double *g, double *b);
extern int   buffer_kill(char *f);
extern int   buffer_update_dvi(char *f, DVI dvi_new);
extern int   buffer_select(char *f);
extern int   buffer_select_any_other(char *f);
extern void  buffer_select_next(int next);

extern IMGCACHE  buffer_current_ic(void);
extern void      buffer_cleanup(void);

extern int   buffer_dump(void);

#endif
